export interface IPlatformService {
    /**
     * Indicates if the current platform is a native mobile app
     * like react-native or flutter.
     */
    isNativeMobile: boolean;
    /**
     * Gets the hostname of the current location.
     *
     * @example window.location.hostname
     */
    getHostname(): string;
    /**
     * Gets the host of the current location.
     *
     * @example window.location.host
     */
    getHost(): string;
    /**
     * Gets the current URL.
     *
     * @example new URL(window.location.href)
     */
    getUrl(): URL;
    /**
     * Gets the origin of the current location.
     *
     * @example window.location.origin
     */
    getOrigin(): string;
    /**
     * Gets the origin to be displayed in the UI.
     *
     * @example window.location.origin
     */
    getDisplayOrigin(): string | undefined;
    getTLD(domain?: string): string | undefined;
    /**
     * Opens a URL.
     *
     * Target options:
     * - 'self': Opens the URL in the current window (default).
     * - 'blank': Opens the URL in a new window.
     *
     * The `features` parameter is passed to the `window.open` function when the target is 'blank'.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/API/Window/open
     */
    openURL(url: string, target?: 'self' | 'blank', features?: string): Promise<void>;
}
