'use client'
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var logger = require('../../../logger/logger.cjs');
var StorageService = require('../StorageService.cjs');

const createStorageService = ({ storage, }) => {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const packValue = (value) => JSON.stringify(value);
    const unpackValue = (value) => JSON.parse(value);
    const getItem = (key) => {
        const value = storage.getItem(key);
        if (!value) {
            return undefined;
        }
        try {
            return unpackValue(value);
        }
        catch (error) {
            logger.logger.error(`Error while parsing ${key} from local storage`, {
                value,
            });
            removeItem(key);
            StorageService.StorageService.events.emit('parseFailure', error, key);
        }
        return undefined;
    };
    const setItem = (key, value) => {
        storage.setItem(key, packValue(value));
    };
    const removeItem = (key) => {
        storage.removeItem(key);
    };
    const getKeys = () => Object.keys(storage);
    return {
        getItem,
        getKeys,
        removeItem,
        setItem,
    };
};

exports.createStorageService = createStorageService;
